
{ config, pkgs, inputs, ... }:

{

  virtualisation.docker = {
    enable = true;
    storageDriver = "btrfs";
    logDriver = "json-file";
  };

  imports =
    [
      ../shared/shared-configuration.nix
      ./kernighan-hardware.nix
      ../shared/services/syncthing.nix
      ../shared/services/gitweb.nix
      ../shared/services/miniflux.nix
      ../shared/services/nginx.nix
      ../shared/services/radicale.nix
      ../shared/services/redmine.nix
      ../shared/services/wallabag.nix
    ];

  networking = {
    hostName = "kernighan";
    firewall = {
      enable = false;
    };
  };

  boot = {
    loader.systemd-boot.enable = true;
    loader.efi.canTouchEfiVariables = true;
    initrd.kernelModules = [ "virtio_gpu" ];
    kernelParams = [ "console=tty" ];
  };

  environment.systemPackages = with pkgs; [
    apacheHttpd # Because we need htpasswd for Radicale, annoyingly
    cifs-utils # To mount Storage Box
    git
    git-crypt
    gnupg
    vim
  ];

  users.users.kamal = {
    isNormalUser = true;
    extraGroups = [
      "docker"
    ];
    openssh.authorizedKeys.keyFiles = [
      ../../users/tsv/authorized_keys
    ];
  };
}
